@@ -157,6 +157,11 @@ format.fp_text <- function( x, type = "wml", ... ){
   } else stop("unimplemented type")
 }
 
+#' @export
+to_wml.fp_text <- function(x, add_ns = FALSE, ...) {
+  format(x, type = "wml")
+}
+
 #' @param x \code{fp_text} object
 #' @examples
 #' print( fp_text (color="red", font.size = 12) )
@@ -356,6 +361,10 @@ format.fp_par = function (x, type = "wml", ...){
   } else stop("unimplemented")
 
 }
+#' @export
+to_wml.fp_par <- function(x, add_ns = FALSE, ...) {
+  format(x, type = "wml")
+}
 
 #' @param x,object \code{fp_par} object
 #' @param ... further arguments - not used
@@ -532,6 +541,11 @@ format.fp_cell = function (x, type = "wml", ...){
   } else stop("unimplemented")
 }
 
+#' @export
+to_wml.fp_cell <- function(x, add_ns = FALSE, ...) {
+  format(x, type = "wml")
+}
+
 #' @export
 #' @rdname fp_cell
 print.fp_cell <- function(x, ...){
